==> roundcubemail-0.2.2.tgz: roundcubemail/program/js/tiny_mce/langs/de.js <==
tinyMCE.addI18n({de:{
common:{
edit_confirm:"Wollen Sie diesen Textbereich mit WYSIWYG bearbeiten?",
apply:"\u00DCbernehmen",
insert:"Einf\u00FCgen",
update:"Aktualisieren",
cancel:"Abbrechen",
close:"Schlie\u00DFen",
browse:"Durchsuchen",
class_name:"Klasse",
not_set:"-- Nicht gesetzt --",
clipboard_msg:"Kopieren, Ausschneiden und Einf\u00FCgen sind im Mozilla Firefox nicht m\u00F6glich.\nM\u00F6chten Sie mehr \u00FCber dieses Problem erfahren?",
clipboard_no_support:"Wird derzeit in Ihrem Browser nicht unterst\u00FCtzt. Bitte benutzen Sie stattdessen die Tastenk\u00FCrzel.",
popup_blocked:"Leider hat Ihr Popup-Blocker ein Fenster unterbunden, das f\u00FCr den Betrieb dieses Programms n\u00F6tig ist. Bitte deaktivieren Sie den Popup-Blocker, um die volle Funktionalit\u00E4t zu erlangen.",
invalid_data:"Fehler: Sie haben ung\u00FCltige Werte eingegeben (rot markiert).",
more_colors:"Weitere Farben"
},
contextmenu:{
align:"Ausrichtung",
left:"Links",
center:"Mittig",
right:"Rechts",
full:"Blocksatz"
},
insertdatetime:{
date_fmt:"%d.%m.%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Datum einf\u00FCgen",
inserttime_desc:"Zeit einf\u00FCgen",
months_long:"Januar,Februar,M\u00E4rz,April,Mai,Juni,Juli,August,September,Oktober,November,Dezember",
months_short:"Jan,Feb,M\u00E4rz,Apr,Mai,Juni,Juli,Aug,Sept,Okt,Nov,Dez",
day_long:"Sonntag,Montag,Dienstag,Mittwoch,Donnerstag,Freitag,Samstag,Sonntag",
day_short:"So,Mo,Di,Mi,Do,Fr,Sa,So"
},
print:{
print_desc:"Drucken"
},
preview:{
preview_desc:"Vorschau"
},
directionality:{
ltr_desc:"Schrift von links nach rechts",
rtl_desc:"Schrift von rechts nach links"
},
layer:{
insertlayer_desc:"Neue Ebene einf\u00FCgen",
forward_desc:"Vor verschieben",
backward_desc:"Zur\u00FCck verschieben",
absolute_desc:"Absolute Positionierung",
content:"Neue Ebene..."
},
save:{
save_desc:"Speichern",
cancel_desc:"Alle \u00C4nderungen verwerfen"
},
nonbreaking:{
nonbreaking_desc:"Gesch\u00FCtztes Leerzeichen einf\u00FCgen"
},
iespell:{
iespell_desc:"Rechtschreibpr\u00FCfung",
download:"ieSpell konnte nicht gefunden werden. Wollen Sie es installieren?"
},
advhr:{
advhr_desc:"Trennlinie"
},
emotions:{
emotions_desc:"Smilies"
},
searchreplace:{
search_desc:"Suchen",
replace_desc:"Suchen/Ersetzen"
},
advimage:{
image_desc:"Bild einf\u00FCgen/ersetzen"
},
advlink:{
link_desc:"Link einf\u00FCgen/bearbeiten"
},
xhtmlxtras:{
cite_desc:"Quellenangabe",
abbr_desc:"Abk\u00FCrzung",
acronym_desc:"Akronym",
del_desc:"Entfernter Text",
ins_desc:"Eingef\u00FCgter Text",
attribs_desc:"Attribute einf\u00FCgen/bearbeiten"
},
style:{
desc:"CSS-Styles bearbeiten"
},
paste:{
paste_text_desc:"Als normalen Text einf\u00FCgen",
paste_word_desc:"Mit Formatierungen (aus Word) einf\u00FCgen",
selectall_desc:"Alles ausw\u00E4hlen"
},
paste_dlg:{
text_title:"Dr\u00FCcken Sie auf Ihrer Tastatur Strg+V, um den Text einzuf\u00FCgen.",
text_linebreaks:"Zeilenumbr\u00FCche beibehalten",
word_title:"Dr\u00FCcken Sie auf Ihrer Tastatur Strg+V, um den Text einzuf\u00FCgen."
},
table:{
desc:"Tabelle erstellen",
row_before_desc:"Zeile oberhalb einf\u00FCgen",
row_after_desc:"Zeile unterhalb einf\u00FCgen",
delete_row_desc:"Zeile entfernen",
col_before_desc:"Spalte links einf\u00FCgen",
col_after_desc:"Spalte rechts einf\u00FCgen",
delete_col_desc:"Spalte l\u00F6schen",
split_cells_desc:"Vereinte Zellen trennen",
merge_cells_desc:"Zellen vereinen",
row_desc:"Eigenschaften der Zeile",
cell_desc:"Eigenschaften der Zelle",
props_desc:"Eigenschaften der Tabelle",
paste_row_before_desc:"Zeile oberhalb aus der Zwischenablage einf\u00FCgen",
paste_row_after_desc:"Zeile unterhalb aus der Zwischenablage einf\u00FCgen",
cut_row_desc:"Zeile ausschneiden",
copy_row_desc:"Zeile kopieren",
del:"Tabelle entfernen",
row:"Zeile",
col:"Spalte",
cell:"Zelle"
},
autosave:{
unload_msg:"Ihre \u00C4nderungen werden verloren gehen, wenn Sie die Seite verlassen."
},
fullscreen:{
desc:"Vollbildschirm"
},
media:{
desc:"Multimedia einbetten/bearbeiten",
edit:"Multimediaeinbettung bearbeiten"
},
fullpage:{
desc:"Dokument-Eigenschaften"
},
template:{
desc:"Vorgefertigten Vorlageninhalt einf\u00FCgen"
},
visualchars:{
desc:"Sichtbarkeit der Steuerzeichen an/aus."
},
spellchecker:{
desc:"Rechtschreibpr\u00FCfung an/aus",
menu:"Einstellungen der Rechtschreibpr\u00FCfung",
ignore_word:"Wort ignorieren",
ignore_words:"Alle ignorieren",
langs:"Sprachen",
wait:"Bitte warten...",
sug:"Vorschl\u00E4ge",
no_sug:"Keine Vorschl\u00E4ge",
no_mpell:"Keine Rechtschreibfehler gefunden."
},
pagebreak:{
desc:"Seitenumbruch Einf\u00FCgen."
}}});

==> roundcubemail-0.5p0.tgz: roundcubemail/program/js/tiny_mce/langs/de.js <==
tinyMCE.addI18n({de:{
common:{
edit_confirm:"Wollen Sie diesen Textbereich mit WYSIWYG bearbeiten?",
apply:"\u00DCbernehmen",
insert:"Einf\u00FCgen",
update:"Aktualisieren",
cancel:"Abbrechen",
close:"Schlie\u00DFen",
browse:"Durchsuchen",
class_name:"CSS-Klasse",
not_set:"- unbestimmt -",
clipboard_msg:"Kopieren, Ausschneiden und Einf\u00FCgen sind im Mozilla Firefox nicht m\u00F6glich.\nM\u00F6chten Sie mehr \u00FCber dieses Problem erfahren?",
clipboard_no_support:"Wird derzeit in Ihrem Browser nicht unterst\u00FCtzt. Bitte benutzen Sie stattdessen die Tastenk\u00FCrzel.",
popup_blocked:"Leider hat Ihr Popup-Blocker ein Fenster unterbunden, das f\u00FCr den Betrieb dieses Programms n\u00F6tig ist. Bitte deaktivieren Sie den Popup-Blocker f\u00FCr diese Seite.",
invalid_data:"Fehler: Sie haben ung\u00FCltige Werte eingegeben (rot markiert).",
more_colors:"Weitere Farben"
},
contextmenu:{
align:"Ausrichtung",
left:"Linksb\u00FCndig",
center:"Zentriert",
right:"Rechtsb\u00FCndig",
full:"Blocksatz"
},
insertdatetime:{
date_fmt:"%d.%m.%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Datum einf\u00FCgen",
inserttime_desc:"Zeit einf\u00FCgen",
months_long:"Januar,Februar,M\u00E4rz,April,Mai,Juni,Juli,August,September,Oktober,November,Dezember",
months_short:"Jan,Feb,M\u00E4r,Apr,Mai,Juni,Juli,Aug,Sept,Okt,Nov,Dez",
day_long:"Sonntag,Montag,Dienstag,Mittwoch,Donnerstag,Freitag,Samstag,Sonntag",
day_short:"So,Mo,Di,Mi,Do,Fr,Sa,So"
},
print:{
print_desc:"Drucken"
},
preview:{
preview_desc:"Vorschau"
},
directionality:{
ltr_desc:"Schrift von links nach rechts",
rtl_desc:"Schrift von rechts nach links"
},
layer:{
insertlayer_desc:"Neue Ebene einf\u00FCgen",
forward_desc:"Nach vorne holen",
backward_desc:"Nach hinten legen",
absolute_desc:"Absolute Positionierung",
content:"Neue Ebene..."
},
save:{
save_desc:"Speichern",
cancel_desc:"Alle \u00C4nderungen verwerfen"
},
nonbreaking:{
nonbreaking_desc:"Gesch\u00FCtztes Leerzeichen einf\u00FCgen"
},
iespell:{
iespell_desc:"Rechtschreibpr\u00FCfung",
download:"ieSpell konnte nicht gefunden werden. Wollen Sie es installieren?"
},
advhr:{
advhr_desc:"Trennlinie"
},
emotions:{
emotions_desc:"Smilies"
},
searchreplace:{
search_desc:"Suchen",
replace_desc:"Suchen/Ersetzen"
},
advimage:{
image_desc:"Bild einf\u00FCgen/ersetzen"
},
advlink:{
link_desc:"Link einf\u00FCgen/bearbeiten"
},
xhtmlxtras:{
cite_desc:"Quellenangabe",
abbr_desc:"Abk\u00FCrzung",
acronym_desc:"Akronym",
del_desc:"Entfernter Text",
ins_desc:"Eingef\u00FCgter Text",
attribs_desc:"Attribute einf\u00FCgen/bearbeiten"
},
style:{
desc:"CSS-Styles bearbeiten"
},
paste:{
paste_text_desc:"Als einfachen Text einf\u00FCgen",
paste_word_desc:"Mit Formatierungen (aus Word) einf\u00FCgen",
selectall_desc:"Alles ausw\u00E4hlen",
plaintext_mode_sticky:"Einf\u00FCgemodus ist nun \"Nur Text\". Erneut klicken (oder das Einf\u00FCgen aus der Zwischenablage) stellt den Normalmodus wieder her.",
plaintext_mode:"Einf\u00FCgemodus ist nun \"Nur Text\". Erneut klicken stellt den Normalmodus wieder her."
},
paste_dlg:{
text_title:"Dr\u00FCcken Sie auf Ihrer Tastatur Strg+V, um den Text einzuf\u00FCgen.",
text_linebreaks:"Zeilenumbr\u00FCche beibehalten",
word_title:"Dr\u00FCcken Sie auf Ihrer Tastatur Strg+V, um den Text einzuf\u00FCgen."
},
table:{
desc:"Tabelle erstellen/bearbeiten",
row_before_desc:"Zeile oberhalb einf\u00FCgen",
row_after_desc:"Zeile unterhalb einf\u00FCgen",
delete_row_desc:"Zeile l\u00F6schen",
col_before_desc:"Spalte links einf\u00FCgen",
col_after_desc:"Spalte rechts einf\u00FCgen",
delete_col_desc:"Spalte l\u00F6schen",
split_cells_desc:"Verbundene Zellen trennen",
merge_cells_desc:"Zellen verbinden",
row_desc:"Eigenschaften der Zeile",
cell_desc:"Eigenschaften der Zelle",
props_desc:"Eigenschaften der Tabelle",
paste_row_before_desc:"Zeile oberhalb aus der Zwischenablage einf\u00FCgen",
paste_row_after_desc:"Zeile unterhalb aus der Zwischenablage einf\u00FCgen",
cut_row_desc:"Zeile ausschneiden",
copy_row_desc:"Zeile kopieren",
del:"Tabelle l\u00F6schen",
row:"Zeile",
col:"Spalte",
cell:"Zelle",
cellprops_delta_width:"150"
},
autosave:{
unload_msg:"Ihre \u00C4nderungen werden verloren gehen, wenn Sie die Seite verlassen.",
restore_content:"Automatisch gespeicherten Inhalt wiederherstellen.",
warning_message:"Wenn Sie den Inhalt wiederherstellen, gehen die aktuellen Daten im Editor verloren.\n\nSind sie sicher, dass Sie den Inhalt wiederherstellen m\u00F6chten?"
},
fullscreen:{
desc:"Vollbildschirm"
},
media:{
desc:"Multimedia einbetten/bearbeiten",
edit:"Multimediaeinbettung bearbeiten"
},
fullpage:{
desc:"Dokument-Eigenschaften"
},
template:{
desc:"Inhalt aus Vorlage einf\u00FCgen"
},
visualchars:{
desc:"Sichtbarkeit der Steuerzeichen an/aus"
},
spellchecker:{
desc:"Rechtschreibpr\u00FCfung an/aus",
menu:"Einstellungen der Rechtschreibpr\u00FCfung",
ignore_word:"Wort ignorieren",
ignore_words:"Alle ignorieren",
langs:"Sprachen",
wait:"Bitte warten...",
sug:"Vorschl\u00E4ge",
no_sug:"Keine Vorschl\u00E4ge",
no_mpell:"Keine Rechtschreibfehler gefunden."
},
pagebreak:{
desc:"Seitenumbruch einf\u00FCgen"
},
advlist:{
types:"Typen",
def:"Standard",
lower_alpha:"a. b. c.",
lower_greek:"1. 2. 3.",
lower_roman:"i. ii. iii.",
upper_alpha:"A. B. C.",
upper_roman:"I. II. III.",
circle:"Kreis",
disc:"Punkt",
square:"Quadrat"
}}});
